@@ -1,4 +1,4 @@
-/*	$Id: kcgi.h,v 1.114 2018/03/06 04:08:36 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.124 2018/06/19 09:20:30 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014--2018 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -53,7 +53,7 @@
 /*
  * Build version.
  */
-#define	KCGI_VBUILD	1
+#define	KCGI_VBUILD	7
 
 /*
  * Version string of major.minor.build (as a literal string).
@@ -324,6 +324,7 @@ enum	kmime {
 	KMIME_APP_JSON,
 	KMIME_APP_OCTET_STREAM,
 	KMIME_APP_PDF,
+	KMIME_APP_XML,
 	KMIME_APP_ZIP,
 	KMIME_IMAGE_GIF,
 	KMIME_IMAGE_JPEG,
@@ -483,18 +484,13 @@ struct	ktemplate {
 	int		 	(*cb)(size_t, void *);
 };
 
-typedef enum kcgi_err (*ktemplate_writef)(const char *, size_t, void *);
-
-struct	ktemplatex {
-	ktemplate_writef	 writer;
-	int			(*fbk)(const char *, size_t, void *);
-};
-
 enum	kcgi_err {
 	KCGI_OK = 0,
 	/* ENOMEM (fork, malloc, etc.). */
 	KCGI_ENOMEM,
 	/* FastCGI request to exit. */
+	KCGI_EXIT,
+	/* FastCGI connection has closed. */
 	KCGI_HUP,
 	/* ENFILE or EMFILE (fd ops). */
 	KCGI_ENFILE,
@@ -506,8 +502,17 @@ enum	kcgi_err {
 	KCGI_SYSTEM
 };
 
+typedef enum kcgi_err (*ktemplate_writef)(const char *, size_t, void *);
+
+struct	ktemplatex {
+	ktemplate_writef	 writer;
+	int			(*fbk)(const char *, size_t, void *);
+};
+
 __BEGIN_DECLS
 
+const char	*kcgi_strerror(enum kcgi_err);
+
 enum kcgi_err	 khttp_body(struct kreq *);
 enum kcgi_err	 khttp_body_compress(struct kreq *, int);
 void		 khttp_free(struct kreq *);
